summaryrefslogtreecommitdiff
path: root/finch/gntmenuutil.h
diff options
context:
space:
mode:
authorGary Kramlich <grim@reaperworld.com>2018-02-15 22:04:57 -0600
committerGary Kramlich <grim@reaperworld.com>2018-02-15 22:04:57 -0600
commitc817ef500261e2364982f6b327df388601089137 (patch)
tree63497e9bb3548c05a40c5c6c850f1b408f013dde /finch/gntmenuutil.h
parentef05f992cedbe39a6d55576962be92b82019f5ae (diff)
downloadpidgin-c817ef500261e2364982f6b327df388601089137.tar.gz
Rename PurpleMenuAction to PurpleActionMenu
Diffstat (limited to 'finch/gntmenuutil.h')
-rw-r--r--finch/gntmenuutil.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/finch/gntmenuutil.h b/finch/gntmenuutil.h
index f449718bfe..1e2ff69a36 100644
--- a/finch/gntmenuutil.h
+++ b/finch/gntmenuutil.h
@@ -40,12 +40,12 @@
/**
* finch_append_menu_action:
* @menu: the GntMenu to add to
* @action: the PurpleMenuAction to add
* @ctx: the callback context, passed as the first argument to
* the PurpleMenuAction's PurpleCallback function.
*
* Add a PurpleMenuAction to a GntMenu.
*/
-void finch_append_menu_action(GntMenu *menu, PurpleMenuAction *action, gpointer ctx);
+void finch_append_menu_action(GntMenu *menu, PurpleActionMenu *action, gpointer ctx);
#endif
@@ -40,12 +40,12 @@
* finch_append_menu_action:
* @menu: the GntMenu to add to
- * @action: the PurpleMenuAction to add
+ * @action: the PurpleActionMenu to add
* @ctx: the callback context, passed as the first argument to
@@ -40,12 +40,12 @@
* @ctx: the callback context, passed as the first argument to
- * the PurpleMenuAction's PurpleCallback function.
+ * the PurpleActionMenu's PurpleCallback function.
*
@@ -40,12 +40,12 @@
*
- * Add a PurpleMenuAction to a GntMenu.
+ * Add a PurpleActionMenu to a GntMenu.
*/